@@ -1,9 +1,13 @@
 import aiohttp
 from .exceptions import NotFound, APIError
 
+ver = "0.8.1"
+
 class RequestClient:
     def __init__(self):
-        self.session = aiohttp.ClientSession()
+        self.session = aiohttp.ClientSession(headers={
+            "User-Agent": "apex2504/python-corona-api v{}".format(ver)
+        })
 
     async def make_request(self, endpoint):
         async with self.session.get(endpoint) as resp:
@@ -12,4 +16,8 @@ class RequestClient:
             elif resp.status != 200:
                 raise APIError('An unexpected error occurred.')
             
-            return await resp.json()
\ No newline at end of file
+            return await resp.json()
+
+    
+    async def close(self):
+        await self.session.close()
\ No newline at end of file
